==> adeptarch_base-9.0.1%2B1.tar.gz: lib/src/widgets/number_filter_view.dart <==
import 'package:adeptarch_base/src/widgets/widgets.dart';
import 'package:adeptarch_base/src/filters/filters.dart';
import 'package:flutter/material.dart';

// ignore_for_file: must_be_immutable
class NumberFilterView extends BaseFilterView<NumberFilter> {
  String textExceptionValueValidation;
  String textValue;
  String textValueMin;
  String textValueMax;
  String textUnspecified;
  String textEqualsTo;
  String textGreaterThan;
  String textGreaterOrEqualThan;
  String textLessThan;
  String textLessOrEqualThan;
  String textRange;

  NumberFilterView({
    FilterController<NumberFilter>? filterController,
    String? hint,
    bool? allowSorting,
    this.textValue = "Value",
    this.textValueMin = "Value min",
    this.textValueMax = "Value max",
    this.textUnspecified = "Unspecified",
    this.textEqualsTo = "Equals to",
    this.textGreaterThan = "Greater than",
    this.textGreaterOrEqualThan = "Greater or equal than",
    this.textLessThan = "Less than",
    this.textLessOrEqualThan = "Less or equal than",
    this.textRange = "Range",
    this.textExceptionValueValidation = "Value must be an integer number.",
  }) : super(
          filterController: filterController,
          hint: hint,
          allowSorting: allowSorting,
        );

  @override
  State createState() => _NumberFilterViewState();
}

class _NumberFilterViewState extends State<NumberFilterView> {
  late Color colorPrimary, colorError, colorTextTertiary;
  final textValueMinController = AdeptTextEditingController();
  final textValueMaxController = AdeptTextEditingController();
  List<DropdownMenuItem<int>>? intFilterActions;

  @override
  void initState() {
    super.initState();
    init();
    listeners();
  }

  void init() {
    onFilterChanged();
    generateActionItems();
  }

  void generateActionItems() {
    intFilterActions = [
      DropdownMenuItem(
        value: NUMBER_FILTER_ALL,
        child: Text(
          widget.textUnspecified,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_EQUALS,
        child: Text(
          widget.textEqualsTo,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_GREATER_THAN,
        child: Text(
          widget.textGreaterThan,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_GREATER_OR_EQUAL_THAN,
        child: Text(
          widget.textGreaterOrEqualThan,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_LESS_THAN,
        child: Text(
          widget.textLessThan,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_LESS_OR_EQUAL_THAN,
        child: Text(
          widget.textLessOrEqualThan,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_RANGE,
        child: Text(
          widget.textRange,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
    ];
  }

  void listeners() {
    widget.filterController.addListener(onFilterChanged);
    textValueMinController.addListener(onValueMinTextChanged);
    textValueMaxController.addListener(onValueMaxTextChanged);
  }

  void onFilterChanged() {
    NumberFilter? filter = widget.filterController.value;
    if (filter != null) {
      textValueMinController.text = "${filter.valueMin ?? ""}";
      textValueMaxController.text = "${filter.valueMax ?? ""}";
    }
  }

  void onValueMinTextChanged() {
    if (TextUtils.isEmpty(textValueMinController.text)) {
      widget.filterController.value?.valueMin = null;
      return;
    }
    int? value = int.tryParse(textValueMinController.text);
    if (value != null) {
      widget.filterController.value?.valueMin = value;
      if (widget.filterController.error != null) {
        widget.filterController.clearError();
        setState(() {});
      }
    } else {
      bool hadError = widget.filterController.error != null;
      widget.filterController.value?.valueMin = null;
      if (!hadError) {
        widget.filterController.error = widget.textExceptionValueValidation;
        setState(() {});
      }
    }
  }

  void onValueMaxTextChanged() {
    if (TextUtils.isEmpty(textValueMaxController.text)) {
      widget.filterController.value?.valueMax = null;
      return;
    }
    int? value = int.tryParse(textValueMaxController.text);
    if (value != null) {
      widget.filterController.value?.valueMax = value;
      if (widget.filterController.error != null) {
        widget.filterController.clearError();
        setState(() {});
      }
    } else {
      bool hadError = widget.filterController.error != null;
      widget.filterController.value?.valueMax = null;
      if (!hadError) {
        widget.filterController.error = widget.textExceptionValueValidation;
        setState(() {});
      }
    }
  }

  void checkColors(context) {
    colorPrimary = Theme.of(context).primaryColor;
    colorError = Theme.of(context).colorScheme.error;
    colorTextTertiary = Colors.grey.shade600;
  }

  @override
  Widget build(BuildContext context) {
    checkColors(context);
    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        if (widget.hint != null)
          Text(
            widget.hint!,
            style: TextStyle(
                color: widget.filterController.value?.paramAction != null
                    ? colorPrimary
                    : colorTextTertiary,
                fontSize: 12),
          ),
        widget.filterController.error == null
            ? const SizedBox()
            : Text(
                widget.filterController.error!,
                style: TextStyle(color: colorError, fontSize: 12),
              ),
        Row(
          children: <Widget>[
            Expanded(
              child: Theme(
                data: ThemeData(brightness: Theme.of(context).brightness),
                child: DropdownButton<int>(
                  isExpanded:
                      widget.filterController.value?.paramAction == null,
                  items: intFilterActions,
                  value: widget.filterController.value?.numberFilterType,
                  onChanged: (numberFilterType) {
                    if (numberFilterType == null) {
                      widget.filterController.reset();
                    } else {
                      int? value = int.tryParse(textValueMinController.text);
                      widget.filterController.value?.numberFilterType =
                          numberFilterType;
                      widget.filterController.value?.valueMin = value;
                      widget.filterController.value?.valueMax = value;
                    }
                    setState(() {});
                  },
                ),
              ),
            ),
            Visibility(
              visible: widget.allowSorting,
              child: Container(
                margin: const EdgeInsets.only(top: 16),
                alignment: Alignment.topCenter,
                child: SortView(
                  sortMode: widget.filterController.value?.sortMode,
                  listener: (oldMode, newMode) {
                    widget.filterController.value?.sortMode = newMode;
                  },
                ),
              ),
            )
          ],
        ),
        Row(
          children: <Widget>[
            Visibility(
              visible: widget.filterController.value?.numberFilterType !=
                  NUMBER_FILTER_ALL,
              child: Expanded(
                child: TextField(
                  controller: textValueMinController,
                  textInputAction: TextInputAction.done,
                  keyboardType: TextInputType.number,
                  decoration: InputDecoration(
                    labelText:
                        widget.filterController.value?.numberFilterType !=
                                NUMBER_FILTER_RANGE
                            ? widget.textValue
                            : widget.textValueMin,
                    contentPadding: const EdgeInsets.all(8),
                    focusedBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(width: 1, color: Colors.grey.shade300),
                    ),
                    enabledBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(width: 1, color: Colors.grey.shade300),
                    ),
                  ),
                ),
              ),
            ),
            Visibility(
              visible: widget.filterController.value?.numberFilterType ==
                  NUMBER_FILTER_RANGE,
              child: const Text(" --- "),
            ),
            Visibility(
              visible: widget.filterController.value?.numberFilterType ==
                  NUMBER_FILTER_RANGE,
              child: Expanded(
                child: TextField(
                  controller: textValueMaxController,
                  textInputAction: TextInputAction.done,
                  keyboardType: TextInputType.number,
                  decoration: InputDecoration(
                    labelText: widget.textValueMax,
                    contentPadding: const EdgeInsets.all(8),
                    focusedBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(width: 1, color: Colors.grey.shade300),
                    ),
                    enabledBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(width: 1, color: Colors.grey.shade300),
                    ),
                  ),
                ),
              ),
            ),
          ],
        ),
      ],
    );
  }

  @override
  void dispose() {
    widget.filterController.removeListener(onFilterChanged);
    super.dispose();
  }
}

==> adeptarch_base-12.0.0%2B1.tar.gz: lib/src/widgets/number_filter_view.dart <==
import 'package:adeptarch_base/src/widgets/widgets.dart';
import 'package:adeptarch_base/src/filters/filters.dart';
import 'package:flutter/material.dart';

// ignore_for_file: must_be_immutable
class NumberFilterView extends BaseFilterView<NumberFilter> {
  String textExceptionValueValidation;
  String textValue;
  String textValueMin;
  String textValueMax;
  String textUnspecified;
  String textEqualsTo;
  String textGreaterThan;
  String textGreaterOrEqualThan;
  String textLessThan;
  String textLessOrEqualThan;
  String textRange;

  NumberFilterView({
    super.filterController,
    super.hint,
    super.allowSorting,
    this.textValue = "Value",
    this.textValueMin = "Value min",
    this.textValueMax = "Value max",
    this.textUnspecified = "Unspecified",
    this.textEqualsTo = "Equals to",
    this.textGreaterThan = "Greater than",
    this.textGreaterOrEqualThan = "Greater or equal than",
    this.textLessThan = "Less than",
    this.textLessOrEqualThan = "Less or equal than",
    this.textRange = "Range",
    this.textExceptionValueValidation = "Value must be an integer number.",
  });

  @override
  State createState() => _NumberFilterViewState();
}

class _NumberFilterViewState extends State<NumberFilterView> {
  late Color colorPrimary, colorError, colorTextTertiary;
  final textValueMinController = AdeptTextEditingController();
  final textValueMaxController = AdeptTextEditingController();
  List<DropdownMenuItem<int>>? intFilterActions;

  @override
  void initState() {
    super.initState();
    init();
    listeners();
  }

  void init() {
    onFilterChanged();
    generateActionItems();
  }

  void generateActionItems() {
    intFilterActions = [
      DropdownMenuItem(
        value: NUMBER_FILTER_ALL,
        child: Text(
          widget.textUnspecified,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_EQUALS,
        child: Text(
          widget.textEqualsTo,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_GREATER_THAN,
        child: Text(
          widget.textGreaterThan,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_GREATER_OR_EQUAL_THAN,
        child: Text(
          widget.textGreaterOrEqualThan,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_LESS_THAN,
        child: Text(
          widget.textLessThan,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_LESS_OR_EQUAL_THAN,
        child: Text(
          widget.textLessOrEqualThan,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
      DropdownMenuItem(
        value: NUMBER_FILTER_RANGE,
        child: Text(
          widget.textRange,
          maxLines: 1,
          overflow: TextOverflow.ellipsis,
        ),
      ),
    ];
  }

  void listeners() {
    widget.filterController.addListener(onFilterChanged);
    textValueMinController.addListener(onValueMinTextChanged);
    textValueMaxController.addListener(onValueMaxTextChanged);
  }

  void onFilterChanged() {
    NumberFilter? filter = widget.filterController.value;
    if (filter != null) {
      textValueMinController.text = "${filter.valueMin ?? ""}";
      textValueMaxController.text = "${filter.valueMax ?? ""}";
    }
  }

  void onValueMinTextChanged() {
    if (TextUtils.isEmpty(textValueMinController.text)) {
      widget.filterController.value?.valueMin = null;
      return;
    }
    int? value = int.tryParse(textValueMinController.text);
    if (value != null) {
      widget.filterController.value?.valueMin = value;
      if (widget.filterController.error != null) {
        widget.filterController.clearError();
        setState(() {});
      }
    } else {
      bool hadError = widget.filterController.error != null;
      widget.filterController.value?.valueMin = null;
      if (!hadError) {
        widget.filterController.error = widget.textExceptionValueValidation;
        setState(() {});
      }
    }
  }

  void onValueMaxTextChanged() {
    if (TextUtils.isEmpty(textValueMaxController.text)) {
      widget.filterController.value?.valueMax = null;
      return;
    }
    int? value = int.tryParse(textValueMaxController.text);
    if (value != null) {
      widget.filterController.value?.valueMax = value;
      if (widget.filterController.error != null) {
        widget.filterController.clearError();
        setState(() {});
      }
    } else {
      bool hadError = widget.filterController.error != null;
      widget.filterController.value?.valueMax = null;
      if (!hadError) {
        widget.filterController.error = widget.textExceptionValueValidation;
        setState(() {});
      }
    }
  }

  void checkColors(context) {
    colorPrimary = Theme.of(context).primaryColor;
    colorError = Theme.of(context).colorScheme.error;
    colorTextTertiary = Colors.grey.shade600;
  }

  @override
  Widget build(BuildContext context) {
    checkColors(context);
    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        if (widget.hint != null)
          Text(
            widget.hint!,
            style: TextStyle(
                color: widget.filterController.value?.paramAction != null
                    ? colorPrimary
                    : colorTextTertiary,
                fontSize: 12),
          ),
        widget.filterController.error == null
            ? const SizedBox()
            : Text(
                widget.filterController.error!,
                style: TextStyle(color: colorError, fontSize: 12),
              ),
        Row(
          children: <Widget>[
            Expanded(
              child: Theme(
                data: ThemeData(brightness: Theme.of(context).brightness),
                child: DropdownButton<int>(
                  isExpanded:
                      widget.filterController.value?.paramAction == null,
                  items: intFilterActions,
                  value: widget.filterController.value?.numberFilterType,
                  onChanged: (numberFilterType) {
                    if (numberFilterType == null) {
                      widget.filterController.reset();
                    } else {
                      int? value = int.tryParse(textValueMinController.text);
                      widget.filterController.value?.numberFilterType =
                          numberFilterType;
                      widget.filterController.value?.valueMin = value;
                      widget.filterController.value?.valueMax = value;
                    }
                    setState(() {});
                  },
                ),
              ),
            ),
            Visibility(
              visible: widget.allowSorting,
              child: Container(
                margin: const EdgeInsets.only(top: 16),
                alignment: Alignment.topCenter,
                child: SortView(
                  sortMode: widget.filterController.value?.sortMode,
                  listener: (oldMode, newMode) {
                    widget.filterController.value?.sortMode = newMode;
                  },
                ),
              ),
            )
          ],
        ),
        Row(
          children: <Widget>[
            Visibility(
              visible: widget.filterController.value?.numberFilterType !=
                  NUMBER_FILTER_ALL,
              child: Expanded(
                child: TextField(
                  controller: textValueMinController,
                  textInputAction: TextInputAction.done,
                  keyboardType: TextInputType.number,
                  decoration: InputDecoration(
                    labelText:
                        widget.filterController.value?.numberFilterType !=
                                NUMBER_FILTER_RANGE
                            ? widget.textValue
                            : widget.textValueMin,
                    contentPadding: const EdgeInsets.all(8),
                    focusedBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(width: 1, color: Colors.grey.shade300),
                    ),
                    enabledBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(width: 1, color: Colors.grey.shade300),
                    ),
                  ),
                ),
              ),
            ),
            Visibility(
              visible: widget.filterController.value?.numberFilterType ==
                  NUMBER_FILTER_RANGE,
              child: const Text(" --- "),
            ),
            Visibility(
              visible: widget.filterController.value?.numberFilterType ==
                  NUMBER_FILTER_RANGE,
              child: Expanded(
                child: TextField(
                  controller: textValueMaxController,
                  textInputAction: TextInputAction.done,
                  keyboardType: TextInputType.number,
                  decoration: InputDecoration(
                    labelText: widget.textValueMax,
                    contentPadding: const EdgeInsets.all(8),
                    focusedBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(width: 1, color: Colors.grey.shade300),
                    ),
                    enabledBorder: OutlineInputBorder(
                      borderSide:
                          BorderSide(width: 1, color: Colors.grey.shade300),
                    ),
                  ),
                ),
              ),
            ),
          ],
        ),
      ],
    );
  }

  @override
  void dispose() {
    widget.filterController.removeListener(onFilterChanged);
    super.dispose();
  }
}
